The official Python API wrapper for Nexus, by Tycho.  
It provides a convenient way to interact with Nexus APIs.

### 📖 [Documentation](https://github.com/TychoTeam/nexus-py/wiki) | [PyPI](https://pypi.org/project/tycho.nexus)

## Features

- **Full Coverage**  
  Supports all features from the API.
- **Maintained**  
  Actively maintained and fully open source for any contributions.
- **Rate Limits**  
  By default, the package handles and queues requests to ensure **near-zero** chances of rate limits.
- **Well Typed**  
  The package is strictly typed and all API data is transformed for ease of use.

#### Check out the documentation for all details.

## Install Latest Release (`pip`)

```sh
pip install tycho.nexus
```

The package has been tested for Python `v3.8+`. It may not work on older versions.
